@@ -1,4 +1,5 @@
 import logging
+import logging.config
 from typing import Optional
 
 import structlog
@@ -39,7 +40,28 @@ class LoggingConfigurator:
             event_dict["name"] = record.name
         return event_dict
 
-    def get_processors(self) -> list:
+    def add_open_telemetry_spans(self, _, __, event_dict):
+        from opentelemetry import trace
+        from opentelemetry.trace import format_span_id, format_trace_id
+
+        span = trace.get_current_span()
+        if not span.is_recording():
+            return event_dict
+
+        ctx = span.get_span_context()
+        parent = getattr(span, "parent", None)
+
+        event_dict.update(
+            {
+                "span_id": format_span_id(ctx.span_id),
+                "trace_id": format_trace_id(ctx.trace_id),
+                "parent_span_id": None if not parent else format_span_id(parent.span_id),
+            }
+        )
+
+        return event_dict
+
+    def get_processors(self, tracing_enabled: bool) -> list:
         processors = [
             contextvars.merge_contextvars,
             self.add_logger_name,
@@ -56,22 +78,34 @@ class LoggingConfigurator:
             structlog.processors.EventRenamer(to="message"),
             structlog.stdlib.ProcessorFormatter.wrap_for_formatter,
         ]
+        if tracing_enabled:
+            processors.insert(3, self.add_open_telemetry_spans)
         return processors
 
-    def configure_structlog(self, custom_processors=None, formatter='json_formatter'):
+    def configure_structlog(
+        self,
+        custom_processors=None,
+        formatter='json_formatter',
+        tracing_enabled=False,
+        extra_loggers_names: Optional[list[str]] = None,
+    ):
 
         if self.setup_logging_dict:
-            logger_init_config = self.config
-            if not self.config:
-                logger_init_config = get_default_logging_conf(
-                    log_level=self.log_level,
-                    own_apps=self.own_apps,
-                    formatter=formatter,
-                )
+            logger_init_config = self.config or get_default_logging_conf(
+                log_level=self.log_level,
+                own_apps=self.own_apps,
+                formatter=formatter,
+            )
+            for extra_logger_name in extra_loggers_names or []:
+                logger_init_config['loggers'][extra_logger_name] = {
+                    "handlers": ["console"],
+                    "level": self.log_level,
+                    "propagate": False,
+                }
 
             logging.config.dictConfig(logger_init_config)
 
-        processors = custom_processors or self.get_processors()
+        processors = custom_processors or self.get_processors(tracing_enabled=tracing_enabled)
 
         structlog.configure(
             processors=processors,
