@@ -3,7 +3,6 @@ from typing import Any
 
 from admin_interface.cache import del_cached_active_theme
 from admin_interface.models import Theme
-from django.conf import settings
 from django.contrib.auth import get_user_model
 from django.core.management import call_command
 from django.core.management.base import BaseCommand
@@ -12,11 +11,21 @@ from payla_utils.settings import payla_utils_settings
 
 
 class Command(BaseCommand):
+    """
+    This management command will init environment based on the current env (local.dev, dev, stage, playground and prod)
+
+    - load fixtures on the first run (when the DB is empty)
+    - setup custom theme for admin_interface
+    - create user when not in prod if `LOCAL_DJANGO_ADMIN_PASSWORD` is set
+
+    APP_NAME and ENVIRONMENT settings are required.
+    """
+
     def add_arguments(self, parser):
         parser.add_argument('--env', type=str, default='', help='force which env to use')
 
     def handle(self, *args: Any, **options: Any):
-        env = options.get('env', None) or settings.ENVIRONMENT
+        env = options.get('env', None) or payla_utils_settings.ENVIRONMENT
         self.setup_theme(env)
         self.setup_initial_fixtures(env=env)
         self.run_extra_commands()
